@@ -34,7 +34,7 @@
 /* KH */
 #define MEMFD 10000
 #define ZIPFD 10001
-int zipfdfd;
+extern int zipfdfd;
 
 /* flags for the st_rdev field of regular files */
  /* file is not compressed, ignore any .z extension */
@@ -106,6 +106,17 @@ int zipfdfd;
 #define	H_SCAN	"%6ho%6ho%6ho%6ho%6ho%6ho%6ho%11lo%6o%11lo"
 #define PH_SCAN  "%6lo%6lo%6lo%6lo%6lo%6lo%6lo%11lo%6o%11lo"
 
+/*
+Below is a handy piece of ASCII art which can be used to decode old
+ASCII format headers.
+
+|23456|23456|23456|23456|23456|23456|23456|23456|23456789ab|23456|23456789ab|-
+|  hdr|  dev|  ino| mode|  uid|  gid|nlink| rdev|     mtime|nmlen|      size|n
+
+
+*/
+
+
 /* extended ASCII format */
 #define	H_PRINT2  "%06o%011lo%06o%06o%06o%06o%06o%011lo%06o%011lo"
 #define PH_SCAN2  "%6lo%11lo%6lo%6lo%6lo%6lo%6lo%11lo%6o%11lo"
@@ -422,6 +433,11 @@ VOIDFN (*signal ())();
      int xwait ();
      void mail(char *who,int vol,char *archive);
 
+int writeall();
+int incheckentry();
+int openincheck();
+void mayberewind();
+
 extern	void clear_args(void);
 extern  void add_arg(char *arg);
 extern  char *compress_arg_list[];
@@ -439,6 +455,8 @@ extern int arfd;
 extern int forceZflag;
 extern char *compressprog;
 extern int compressargs;
+extern int rewindfd;
+extern char *ignorewarnings;
 
 /* Note for porters: we use the ulonglong type in calculations with
    integers which should be large enough to hold the size of 1 tape
@@ -480,4 +498,4 @@ typedef  unsigned long ulonglong;
 #endif
 
 ulonglong optsize ();
-
+void update_aruntil();
