@@ -12,15 +12,12 @@
 
 #include "patchlevel.h"
 
-
-#ifndef	major
-#include <sys/sysmacros.h>
-#endif /* major */
-
 #include "afio.h"
 
 int matchcompext(char *);
 
+int zipfdfd;
+
 /* default value vor gzip 1.2.3 */
 int gzipfactor=6;
 
@@ -165,6 +162,8 @@ int setupgzip(char *name)
 
  if(pipe(pipedes)==-1) { perror("pipe"); return -1; }
 
+ mayberewind();
+
  if ((comppid = xfork ("out(), compressing", NODIE)) == 0) 
     {		
       if (arfd != STDIN && arfd != STDOUT) VOID close (arfd);
@@ -260,12 +259,15 @@ compressfile (fdp, name, asb, cratio)
    asb->sb_rdev |= RDEV_NOTCOMPR;
 
   namelen = strlen (name);
-  /* compress only if no links and not already compressed
-     and length is at least threshold.  */
-  if (!lflag &&
-      (asb->sb_nlink == 1) &&
-      ((!matchcompext(name) &&
-      (asb->sb_size >= compthreshold)) || forceZflag)
+  /* Hard link handling code will break if we do compression on the 
+     file, so try to compress only if no links or hard link handling.
+
+     Also only try to compress if not already compressed,
+     or length is >= threshold, but always try if we force compression
+  */
+  if ( (lflag || (asb->sb_nlink == 1)) &&
+       ((!matchcompext(name) && (asb->sb_size >= compthreshold))
+         || forceZflag)
      )
   {  
     /* make sure compress could put on the .Z */
